@@ -64,6 +64,8 @@
 #include "actions/gobgp_action.hpp"
 #endif
 
+#include "bgp_protocol_flow_spec.hpp"
+
 // Yes, maybe it's not an good idea but with this we can guarantee working code in example plugin
 #include "example_plugin/example_collector.hpp"
 
@@ -115,6 +117,11 @@
 #include "metrics/graphite.hpp"
 #include "metrics/influxdb.hpp"
 
+// It's not enabled by default and we enable it only when we have Clickhouse libraries on platform
+#ifdef ENABLE_CLICKHOUSE_SUPPORT
+#include "metrics/clickhouse.hpp"
+#endif
+
 #ifdef KAFKA
 #include <cppkafka/cppkafka.h>
 #endif
@@ -157,9 +164,6 @@ unsigned int stats_thread_initial_call_delay = 30;
 
 std::string reporting_server = "community-stats.fastnetmon.com";
 
-// Path to temporarily store backtrace when fatal failure happened
-std::string backtrace_path = "/var/log/fastnetmon_backtrace.dump";
-
 // Each this seconds we will check about available data in bucket
 unsigned int check_for_availible_for_processing_packets_buckets = 1;
 
@@ -239,11 +243,16 @@ bool monitor_openvz_vps_ip_addresses = false;
 // We will announce whole subnet instead single IP with BGP if this flag enabled
 bool exabgp_announce_whole_subnet = false;
 
+std::string exabgp_command_pipe = "";
+
 // We will announce only /32 host
 bool exabgp_announce_host = false;
 
 ban_settings_t global_ban_settings;
 
+// We use these flow spec rules as custom whitelist
+std::vector<flow_spec_rule_t> static_flowspec_based_whitelist;
+
 void init_global_ban_settings() {
     // ban Configuration params
     global_ban_settings.enable_ban_for_pps              = false;
@@ -371,6 +380,8 @@ uint64_t our_ipv6_packets = 0;
 uint64_t incoming_total_flows_speed = 0;
 uint64_t outgoing_total_flows_speed = 0;
 
+uint64_t total_flowspec_whitelist_packets         = 0;
+
 // Network counters for IPv6
 abstract_subnet_counters_t<subnet_ipv6_cidr_mask_t, subnet_counter_t> ipv6_subnet_counters;
 
@@ -423,7 +434,6 @@ std::string exabgp_community_subnet = "";
 std::string exabgp_community_host   = "";
 
 
-std::string exabgp_command_pipe = "/var/run/exabgp.cmd";
 std::string exabgp_next_hop     = "";
 
 // Graphite monitoring
@@ -1126,28 +1136,94 @@ void subnet_vectors_allocator(prefix_t* prefix, void* data) {
     logger << log4cpp::Priority::INFO << "Successfully allocated " << ipv4_host_counters.average_speed_map.size() << " counters";
 }
 
-bool load_our_networks_list() {
-    if (file_exists(fastnetmon_platform_configuration.white_list_path)) {
-        unsigned int network_entries                      = 0;
-        std::vector<std::string> network_list_from_config = read_file_to_vector(fastnetmon_platform_configuration.white_list_path);
+// Load flow spec based whitelist
+bool load_whitelist_rules() {
+    if (!file_exists(fastnetmon_platform_configuration.whitelist_rules_path)) {
+	return true;
+    }
 
-        for (std::vector<std::string>::iterator ii = network_list_from_config.begin(); ii != network_list_from_config.end(); ++ii) {
-            std::string text_subnet = *ii;
-            if (text_subnet.empty()) {
-                continue;
-            }
-            if (is_v4_host(text_subnet)) {
-                logger << log4cpp::Priority::INFO << "Assuming /32 netmask for " << text_subnet;
-                text_subnet += "/32";
-            } else if (!is_cidr_subnet(text_subnet)) {
-                logger << log4cpp::Priority::ERROR << "Can't parse line from whitelist: " << text_subnet;
-                continue;
-            }
-            network_entries++;
-            make_and_lookup(whitelist_tree_ipv4, text_subnet.c_str());
+    auto whitelist_rules_json = read_file_to_vector(fastnetmon_platform_configuration.whitelist_rules_path);
+
+    logger << log4cpp::Priority::INFO << "Read " << whitelist_rules_json.size() << " whitelist rules from configuration";
+
+    for (auto json_encoded_flow_spec : whitelist_rules_json) {
+        flow_spec_rule_t flow_spec_rule;
+
+        bool need_action_section = false;
+
+        bool parse_result =
+	    read_flow_spec_from_json_to_native_format(json_encoded_flow_spec, flow_spec_rule, need_action_section);
+    
+        if (!parse_result) {
+	    logger << log4cpp::Priority::ERROR << "Cannot parse flowspec whitelist rule: " << json_encoded_flow_spec;
+	    continue;
         }
 
-        logger << log4cpp::Priority::INFO << "We loaded " << network_entries << " networks from whitelist file";
+        // Print rule to verify that parser worked correctly
+        std::string flow_spec_rule_as_json_to_print;
+
+        if (encode_flow_spec_to_json(flow_spec_rule, flow_spec_rule_as_json_to_print, false)) {
+	    logger << log4cpp::Priority::DEBUG << "Loaded rule " << flow_spec_rule_as_json_to_print;
+        } else {
+	    logger << log4cpp::Priority::ERROR << "Cannot encode flow spec rule for printing";
+        }
+
+        static_flowspec_based_whitelist.push_back(flow_spec_rule);
+    }
+
+    logger << log4cpp::Priority::INFO << "Loaded " << static_flowspec_based_whitelist.size() << " whitelist rules";
+
+    return true;
+}
+
+bool load_our_networks_list() {
+    if (file_exists(fastnetmon_platform_configuration.white_list_path)) {
+        std::vector<std::string> network_list_from_config =
+	    read_file_to_vector(fastnetmon_platform_configuration.white_list_path);
+
+        uint32_t ipv4_whitelists = 0;
+        uint32_t ipv6_whitelists = 0;
+
+        for (const auto& subnet_raw : network_list_from_config) {
+	    // Trim leading and trailing spaces
+	    std::string subnet = boost::algorithm::trim_copy(subnet_raw);
+
+            if (subnet.empty()) {
+                continue;
+	    }
+
+	    // Ignore comments
+            if (subnet.find("#") == 0) {
+		continue;
+	    }
+
+            if (strstr(subnet.c_str(), ":") == NULL) {
+                if (!is_cidr_subnet(subnet)) {
+		    logger << log4cpp::Priority::ERROR << "Cannot parse " << subnet << " as IPv4 prefix";
+                    continue;
+		}
+		    
+		// IPv4
+                ipv4_whitelists++;
+                make_and_lookup(whitelist_tree_ipv4, subnet.c_str());
+            } else {
+                // IPv6
+		
+		// Verify IPv6 prefix format    
+		subnet_ipv6_cidr_mask_t ipv6_subnet;
+
+		if (!read_ipv6_subnet_from_string(ipv6_subnet, subnet)) {
+                    logger << log4cpp::Priority::ERROR << "Cannot parse " << subnet << " as IPv6 prefix";
+		    continue;
+		}
+                
+		ipv6_whitelists++;
+                make_and_lookup_ipv6(whitelist_tree_ipv6, subnet.c_str());
+            }
+        }
+
+        logger << log4cpp::Priority::INFO << "We loaded " << ipv4_whitelists << " IPv4 networks and " << ipv6_whitelists
+           << " IPv6 networks from whitelist";
     }
 
     std::vector<std::string> networks_list_ipv4_as_string;
@@ -1195,11 +1271,11 @@ bool load_our_networks_list() {
     }
 
     if (monitor_local_ip_addresses && file_exists("/sbin/ip")) {
-        logger << log4cpp::Priority::INFO << "We are working on Linux and could use ip tool for detecting local IP's";
+        logger << log4cpp::Priority::INFO << "On Linux we can use ip tool to detect local IPs";
 
         ip_addresses_list_t ip_list = get_local_ip_v4_addresses_list();
 
-        logger << log4cpp::Priority::INFO << "We found " << ip_list.size() << " local IP addresses and will monitor they";
+        logger << log4cpp::Priority::INFO << "We found " << ip_list.size() << " local IP addresses";
 
         for (ip_addresses_list_t::iterator iter = ip_list.begin(); iter != ip_list.end(); ++iter) {
             // TODO: add IPv6 here
@@ -1211,18 +1287,29 @@ bool load_our_networks_list() {
         std::vector<std::string> network_list_from_config =
             read_file_to_vector(fastnetmon_platform_configuration.networks_list_path);
 
-        for (std::vector<std::string>::iterator line_itr = network_list_from_config.begin();
-             line_itr != network_list_from_config.end(); ++line_itr) {
+        for (const auto& subnet_raw : network_list_from_config) {
+            // Trim leading and trailing spaces
+            std::string subnet = boost::algorithm::trim_copy(subnet_raw);
 
-            if (line_itr->length() == 0) {
+            if (subnet.empty()) {
+                // Empty line
+                continue;
+            }
+
+            if (subnet.length() == 0) {
                 // Skip blank lines in subnet list file silently
                 continue;
             }
 
-            if (strstr(line_itr->c_str(), ":") == NULL) {
-                networks_list_ipv4_as_string.push_back(*line_itr);
+            // Ignore comments
+            if (subnet.find("#") == 0) {
+                continue;
+            }
+
+            if (strstr(subnet.c_str(), ":") == NULL) {
+                networks_list_ipv4_as_string.push_back(subnet);
             } else {
-                networks_list_ipv6_as_string.push_back(*line_itr);
+                networks_list_ipv6_as_string.push_back(subnet);
             }
         }
 
@@ -1413,7 +1500,7 @@ void init_logging(bool log_to_console) {
         logger.addAppender(appender);
     }
 
-    logger << log4cpp::Priority::INFO << "Logger initialized!";
+    logger << log4cpp::Priority::INFO << "Logger initialized";
 }
 
 void reconfigure_logging_level(const std::string& logging_level) {
@@ -1519,7 +1606,7 @@ void redirect_fds() {
 // Handles fatal failure of FastNetMon's daemon
 void fatal_signal_handler(int signum) {
     ::signal(signum, SIG_DFL);
-    boost::stacktrace::safe_dump_to(backtrace_path.c_str());
+    boost::stacktrace::safe_dump_to(fastnetmon_platform_configuration.backtrace_path.c_str());
     ::raise(SIGABRT);
 }
 
@@ -1650,9 +1737,9 @@ int main(int argc, char** argv) {
 
     init_logging(log_to_console);
 
-    if (std::filesystem::exists(backtrace_path)) {
+    if (std::filesystem::exists(fastnetmon_platform_configuration.backtrace_path)) {
         // there is a backtrace
-        std::ifstream ifs(backtrace_path);
+        std::ifstream ifs(fastnetmon_platform_configuration.backtrace_path);
 
         boost::stacktrace::stacktrace st = boost::stacktrace::stacktrace::from_dump(ifs);
         logger << log4cpp::Priority::ERROR << "Previous run crashed, you can find stack trace below";
@@ -1660,7 +1747,7 @@ int main(int argc, char** argv) {
 
         // cleaning up
         ifs.close();
-        std::filesystem::remove(backtrace_path);
+        std::filesystem::remove(fastnetmon_platform_configuration.backtrace_path);
     }
 
 #ifdef FASTNETMON_API
@@ -1763,6 +1850,8 @@ int main(int argc, char** argv) {
 
     load_our_networks_list();
 
+    load_whitelist_rules();
+
     // We should specify size of circular buffers here
     packet_buckets_ipv4_storage.set_buffers_capacity(ban_details_records_count);
 
